==> elephant-archives-domain-0.0.310-sources.jar: com/xforceplus/elephantarchives/metadata/PageMeta.java <==
package com.xforceplus.elephantarchives.metadata;

/**
 *
 * @author ultraman
 * @since 2021-04-28
 */

public class PageMeta {
    public interface StyleSetup {
        static String code() {
            return "styleSetup";
        }
        static String name() {
            return "样式设置";
        }
    }
    public interface StorageManagement {
        static String code() {
            return "storageManagement";
        }
        static String name() {
            return "库位管理";
        }
    }
    public interface WatermarkSetup {
        static String code() {
            return "watermarkSetup";
        }
        static String name() {
            return "水印设置";
        }
    }
    public interface VoucherReceive {
        static String code() {
            return "voucherReceive";
        }
        static String name() {
            return "档案接收";
        }
    }
    public interface VoucherArrangement {
        static String code() {
            return "voucherArrangement";
        }
        static String name() {
            return "档案整理";
        }
    }
    public interface VoucherSafekeeping {
        static String code() {
            return "voucherSafekeeping";
        }
        static String name() {
            return "档案保管";
        }
    }
    public interface FilingHandle {
        static String code() {
            return "filingHandle";
        }
        static String name() {
            return "立卷待办";
        }
    }
    public interface Location {
        static String code() {
            return "location";
        }
        static String name() {
            return "新库位";
        }
    }
    public interface BorrowApplyInfo {
        static String code() {
            return "borrowApplyInfo";
        }
        static String name() {
            return "借阅申请管理";
        }
    }
    public interface Volume {
        static String code() {
            return "volume";
        }
        static String name() {
            return "档案待授权列表";
        }
    }
    public interface ConfigSettings {
        static String code() {
            return "configSettings";
        }
        static String name() {
            return "系统配置";
        }
    }
    public interface VolumeOperation {
        static String code() {
            return "volumeOperation";
        }
        static String name() {
            return "档案分册";
        }
    }
    public interface GrantVolume {
        static String code() {
            return "grantVolume";
        }
        static String name() {
            return "档案已授权列表页";
        }
    }
    public interface Voucher {
        static String code() {
            return "voucher";
        }
        static String name() {
            return "档案查询";
        }
    }
    public interface Enterwarehouse {
        static String code() {
            return "enterwarehouse";
        }
        static String name() {
            return "档案入库";
        }
    }
    public interface BorrowApplyUser {
        static String code() {
            return "borrowApplyUser";
        }
        static String name() {
            return "借阅申请人";
        }
    }
    public interface Grant {
        static String code() {
            return "grant";
        }
        static String name() {
            return "已授权详情页";
        }
    }
    public interface Style {
        static String code() {
            return "style";
        }
        static String name() {
            return "样式设置";
        }
    }
    public interface BorrowApplyExamine {
        static String code() {
            return "borrowApplyExamine";
        }
        static String name() {
            return "借阅申请审核";
        }
    }
    public interface BorrowApplyExamineManager {
        static String code() {
            return "borrowApplyExamineManager";
        }
        static String name() {
            return "借阅申请审核-管理员";
        }
    }
    public interface DirectoryManage {
        static String code() {
            return "directoryManage";
        }
        static String name() {
            return "目录管理";
        }
    }
    public interface ArchiveTypeManage {
        static String code() {
            return "archiveTypeManage";
        }
        static String name() {
            return "档案类型管理";
        }
    }
    public interface FilingWaitCheck {
        static String code() {
            return "filingWaitCheck";
        }
        static String name() {
            return "待归档档案列表";
        }
    }
    public interface FilingChecking {
        static String code() {
            return "filingChecking";
        }
        static String name() {
            return "归档审批中档案列表";
        }
    }
    public interface FilingChecked {
        static String code() {
            return "filingChecked";
        }
        static String name() {
            return "已归档(审批通过)档案";
        }
    }
    public interface UnVoucher {
        static String code() {
            return "unVoucher";
        }
        static String name() {
            return "非凭证类档案查询";
        }
    }
    public interface UnVoucherCollect {
        static String code() {
            return "unVoucherCollect";
        }
        static String name() {
            return "非凭证类档案采集";
        }
    }
}

==> elephant-archives-domain-0.0.327-sources.jar: com/xforceplus/elephantarchives/metadata/PageMeta.java <==
package com.xforceplus.elephantarchives.metadata;

/**
 *
 * @author ultraman
 * @since 2021-05-21
 */

public class PageMeta {
    public interface StyleSetup {
        static String code() {
            return "styleSetup";
        }
        static String name() {
            return "样式设置";
        }
    }
    public interface StorageManagement {
        static String code() {
            return "storageManagement";
        }
        static String name() {
            return "库位管理";
        }
    }
    public interface WatermarkSetup {
        static String code() {
            return "watermarkSetup";
        }
        static String name() {
            return "水印设置";
        }
    }
    public interface VoucherReceive {
        static String code() {
            return "voucherReceive";
        }
        static String name() {
            return "档案接收";
        }
    }
    public interface VoucherArrangement {
        static String code() {
            return "voucherArrangement";
        }
        static String name() {
            return "档案整理";
        }
    }
    public interface VoucherSafekeeping {
        static String code() {
            return "voucherSafekeeping";
        }
        static String name() {
            return "档案保管";
        }
    }
    public interface FilingHandle {
        static String code() {
            return "filingHandle";
        }
        static String name() {
            return "立卷待办";
        }
    }
    public interface Location {
        static String code() {
            return "location";
        }
        static String name() {
            return "新库位";
        }
    }
    public interface BorrowApplyInfo {
        static String code() {
            return "borrowApplyInfo";
        }
        static String name() {
            return "借阅申请管理";
        }
    }
    public interface Volume {
        static String code() {
            return "volume";
        }
        static String name() {
            return "档案待授权列表";
        }
    }
    public interface ConfigSettings {
        static String code() {
            return "configSettings";
        }
        static String name() {
            return "系统配置";
        }
    }
    public interface VolumeOperation {
        static String code() {
            return "volumeOperation";
        }
        static String name() {
            return "档案分册";
        }
    }
    public interface GrantVolume {
        static String code() {
            return "grantVolume";
        }
        static String name() {
            return "档案已授权列表页";
        }
    }
    public interface Voucher {
        static String code() {
            return "voucher";
        }
        static String name() {
            return "档案查询";
        }
    }
    public interface Enterwarehouse {
        static String code() {
            return "enterwarehouse";
        }
        static String name() {
            return "档案入库";
        }
    }
    public interface BorrowApplyUser {
        static String code() {
            return "borrowApplyUser";
        }
        static String name() {
            return "借阅申请人";
        }
    }
    public interface Grant {
        static String code() {
            return "grant";
        }
        static String name() {
            return "已授权详情页";
        }
    }
    public interface Style {
        static String code() {
            return "style";
        }
        static String name() {
            return "样式设置";
        }
    }
    public interface BorrowApplyExamine {
        static String code() {
            return "borrowApplyExamine";
        }
        static String name() {
            return "借阅申请审核";
        }
    }
    public interface BorrowApplyExamineManager {
        static String code() {
            return "borrowApplyExamineManager";
        }
        static String name() {
            return "借阅申请审核-管理员";
        }
    }
    public interface DirectoryManage {
        static String code() {
            return "directoryManage";
        }
        static String name() {
            return "目录管理";
        }
    }
    public interface ArchiveTypeManage {
        static String code() {
            return "archiveTypeManage";
        }
        static String name() {
            return "档案类型管理";
        }
    }
    public interface FilingWaitCheck {
        static String code() {
            return "filingWaitCheck";
        }
        static String name() {
            return "待审批";
        }
    }
    public interface FilingChecking {
        static String code() {
            return "filingChecking";
        }
        static String name() {
            return "审批中";
        }
    }
    public interface FilingChecked {
        static String code() {
            return "filingChecked";
        }
        static String name() {
            return "已归档";
        }
    }
    public interface UnVoucher {
        static String code() {
            return "unVoucher";
        }
        static String name() {
            return "非凭证类档案查询";
        }
    }
    public interface UnVoucherCollect {
        static String code() {
            return "unVoucherCollect";
        }
        static String name() {
            return "非凭证类档案采集";
        }
    }
    public interface EVatInvoice {
        static String code() {
            return "eVatInvoice";
        }
        static String name() {
            return "电子票夹";
        }
    }
    public interface VolumeAppraisalApply {
        static String code() {
            return "volumeAppraisalApply";
        }
        static String name() {
            return "档案鉴定申请单列表";
        }
    }
    public interface VolumeAppraisalAdd {
        static String code() {
            return "volumeAppraisalAdd";
        }
        static String name() {
            return "待添加鉴定档案列表";
        }
    }
}
